==> was-plugin-1.2.2.jar: com/xebialabs/deployit/plugin/was/step/create-was-managed-apache-web-server.py <==
#
# Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
#
# Your use of XebiaLabs Software and Documentation is subject to the Personal
# License Agreement.
#
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
#
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# "Documentation" means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to  (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

import sys

args = []
args.append('-name')
args.append(webserver['name'])
args.append('-templateName')
args.append(webserver['webServerVendorType'])
serverconfig = []
serverconfig.append('-pluginInstallRoot')
serverconfig.append(webserver['pluginInstallationDirPath'])
serverconfig.append('-webPort')
serverconfig.append(webserver['port'])
args.append('-serverConfig')
args.append(serverconfig)

print 'Deployit INFO: Creating web server ' + webserver['name'] + ' on node ' + node['name']
AdminTask.createWebServer(node['name'], args)

print 'Deployit INFO: Saving configuration'
AdminConfig.save()

==> was-plugin-1.3.1.jar: com/xebialabs/deployit/plugin/was/step/create-was-managed-apache-web-server.py <==
#
# Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
#
# Your use of XebiaLabs Software and Documentation is subject to the Personal
# License Agreement.
#
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
#
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# "Documentation" means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

import sys

args = []
args.append('-name')
args.append(webserver['name'])
args.append('-templateName')
args.append(webserver['webServerVendorType'])
serverconfig = []
serverconfig.append('-pluginInstallRoot')
serverconfig.append(webserver['pluginInstallationDirPath'])
serverconfig.append('-webPort')
serverconfig.append(webserver['port'])
args.append('-serverConfig')
args.append(serverconfig)

print "Creating web server " + webserver['name'] + " on node " + node['nodeName']
AdminTask.createWebServer(node['nodeName'], args)

print "Saving configuration"
AdminConfig.save()
